use domain::entities::player_info;
use domain::entities::prelude::PlayerInfo;
use domain::dto::player_info::PlayerInfoRegister;
use library::db;
use library::resp::response::ResErr::{ErrPerm, ErrSystem};
use library::resp::response::{ResOK, ResResult};
use sea_orm::{ColumnTrait, EntityTrait, PaginatorTrait, QueryFilter, Set};

pub async fn register(req: PlayerInfoRegister) -> ResResult<ResOK<()>> {
    match PlayerInfo::find()
        .filter(player_info::Column::PlatformId.eq(req.platform_id.clone().unwrap()))
        .count(db!())
        .await
    {
        Err(err) => {
            tracing::error!(error = ?err, "查询账号失败");
            return Err(ErrSystem(None));
        }
        Ok(v) => {
            if v > 0 {
                return Err(ErrPerm(Some("用户已存在".to_string())));
            }
        }
    }

    let now = chrono::Local::now().naive_local();

    let model = player_info::ActiveModel {
        username: Set(req.username.unwrap()),
        email: Set(Option::from(req.email)),
        platform_id: Set(req.platform_id.unwrap()),
        user_type: Set(req.user_type.unwrap()),
        country_code: Set(req.country_code.unwrap()),
        created_at: Set(now),
        ..Default::default()
    };

    if let Err(err) = PlayerInfo::insert(model).exec(db!()).await {
        tracing::error!(error = ?err, "添加账号失败");
        return Err(ErrSystem(None));
    }

    Ok(ResOK(None))
}
